@@ -102,7 +102,7 @@ BEAM::BEAM (GLOBALDATA *global, ENVIRONMENT *env, double xpos, double ypos, int
       maxAge = 10 * (type - SML_LIGHTNING + 1);
       numPoints = 4 + rand () % 10;
       color = WHITE;
-      play_sample ((SAMPLE *) _global->sounds[LIGHTNING_SOUND], 128 + (radius * 10), 128, 500 + (radius * 50), 0);
+      play_sample ((SAMPLE *) _global->sounds[LIGHTNING_SOUND], env->scaleVolume(128 + (radius * 10)), 128, 500 + (radius * 50), 0);
     }
   else
     {
