@@ -29,7 +29,7 @@ BUTTON::BUTTON(GLOBALDATA *global, ENVIRONMENT *env, int x1, int y1,
 
 void BUTTON::draw (BITMAP *dest)
 {
-  draw_sprite (dest, (BITMAP *)(isMouseOver())?((isPressed())?depressed:hover):bmp, location.x, location.y);
+  draw_sprite (dest, (BITMAP *)(isMouseOver()?(isPressed()?depressed:hover):bmp), location.x, location.y);
   if (text)
     textout_centre_ex (dest, font, text, location.x+75, location.y + 6, WHITE, -1);
   _env->make_update (location.x, location.y, xl, yl);
@@ -56,7 +56,7 @@ int BUTTON::isPressed()
 {
   if ((mouse_b == 1) && isMouseOver ())
     {
-      play_sample (click, 128, 128, 1000, 0);
+      play_sample (click, _env->scaleVolume(128), 128, 1000, 0);
       return 1;
     }
   else
