@@ -73,6 +73,7 @@ ENVIRONMENT::ENVIRONMENT (GLOBALDATA *global):_global(global),done(NULL),fp(NULL
   waiting_terrain = NULL;
   _global = global;
   global_tank_index = 0;
+  volume_factor = MAX_VOLUME_FACTOR;
 
   initialise ();
   #ifdef THREADS
@@ -1178,3 +1179,20 @@ TANK *ENVIRONMENT::Get_Next_Tank(int *wrapped_around)
    return order[index];
 }
 
+void ENVIRONMENT::increaseVolume()
+{
+  if (volume_factor < MAX_VOLUME_FACTOR)
+    ++volume_factor;
+}
+
+void ENVIRONMENT::decreaseVolume()
+{
+  if (volume_factor > 0)
+    --volume_factor;
+}
+
+int ENVIRONMENT::scaleVolume(int vol) const
+{
+    return (vol * volume_factor) / MAX_VOLUME_FACTOR;
+}
+
