@@ -77,6 +77,9 @@ enum wallTypes
 #define _GET_G(x) ((x & 0x00ff00) >> 8)
 #define _GET_B(x) (x & 0x0000ff)
 
+// max volume factor: means that the interval 0% -> 100% is splitted in 5
+#define MAX_VOLUME_FACTOR 5
+
 #include "tank.h"
 //class TANK;
 //class MISSILE;
@@ -142,6 +145,8 @@ class ENVIRONMENT
     int number_of_bitmaps;
     int current_drawing_mode;
     int global_tank_index;
+    int volume_factor;  // from 0 (no volume) to MAX_VOLUME_FACTOR
+
 
     ENVIRONMENT (GLOBALDATA *global);
     ~ENVIRONMENT ();
@@ -176,6 +181,9 @@ class ENVIRONMENT
     void Set_Wall_Colour();
     bool Get_Boxed_Mode(GLOBALDATA *global);
     TANK *Get_Next_Tank(int *wrapped_around);
+    void increaseVolume();
+    void decreaseVolume();
+    int scaleVolume(int vol) const;
   };
 
 #endif
