@@ -97,7 +97,7 @@ The function returns TRUE on success and
 FALSE is an error occures.
 -- Jesse
 */
-int Load_Game(GLOBALDATA *global, ENVIRONMENT *env)
+int Load_Game(GLOBALDATA *global, ENVIRONMENT * /*env*/)
 {
   char line[512];
   char *field, *value;
@@ -386,14 +386,13 @@ void renderTextLines (GLOBALDATA *global, ENVIRONMENT *env,
   const int textheight_s = textheight * spacing ;
   int yOffset = scrollOffset;
   char *text;
-  int tLen, count;
+  int count;
 
   for (count = 0;
        (count < lines->total_lines) && (yOffset < global->screenHeight);
        count++)
     {
       text = lines->complete_text[count];
-      tLen = text_length (fnt, text);
 
           textout_centre_ex (env->db, fnt, text,
                              global->halfWidth + 2, global->halfHeight + yOffset + 2, BLACK, -1);
