@@ -15,7 +15,7 @@ FLOATTEXT::FLOATTEXT (GLOBALDATA *global, ENVIRONMENT *env, char *text, int xpos
       if (text)
         set_text (text);
       else
-        set_text( "");
+        set_text(NULL);
       set_color (color);
       _align = alignment;
       _global = global;
@@ -108,7 +108,11 @@ void FLOATTEXT::setEnvironment(ENVIRONMENT *env)
 
 
 void FLOATTEXT::draw(BITMAP *dest)
-  {
+{
+      // If there is no text then we have nothing to draw
+      if (! _text)
+         return;
+
       if (_current.w)
         {
           double dFrontFade		=	1.0;
@@ -187,32 +191,23 @@ void FLOATTEXT::draw(BITMAP *dest)
 }
 
 
-/*
-This is too limiting, creating a more flexible text setting function below.
--- Jesse
-void FLOATTEXT::set_text(char *text)
- {
-      strncpy (_text, text, 80);
-      if (strlen (text) > 0)
-        {
-          _current.w = text_length (font, _text) + 3;
-          _text[79] = '\0';
-        }
-      else
-        _current.w = 0;
-      _current.h = text_height (font) + 15;
-}
-*/
 
 // Returns TRUE on success or FALSE on failure.
 int FLOATTEXT::set_text(char *text)
 {
-   int my_length = strlen(text);
+   // int my_length = strlen(text);
+   int my_length;
 
    // clean up old text
    if (_text)
+   {
       free(_text);
-    
+      _text = NULL;
+   }
+   if (! text)
+      return TRUE;
+
+   my_length = strlen(text);
    _text = (char *) calloc( my_length + 1, sizeof(char));
    if (! _text)
       return FALSE;
