@@ -192,7 +192,6 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
             else if (my_class == MISSILE_CLASS)
             {
               TANK *shooting_tank = NULL;
-              BEAM *defense_beam;
               int angle_to_fire;
 
               missile = (MISSILE *) my_object;
@@ -206,7 +205,7 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
               {
                   // (shooting_tank->x < missile->x) ? angle_to_fire = 135 : angle_to_fire = 225;
                   angle_to_fire = atan2(labs(shooting_tank->y - 10 - missile->y), (missile->x - shooting_tank->x)) * 180 / 3.14159265 + 90;
-                  defense_beam = new BEAM(global, env, shooting_tank->x, shooting_tank->y - 10, angle_to_fire, SML_LAZER);
+                  new BEAM(global, env, shooting_tank->x, shooting_tank->y - 10, angle_to_fire, SML_LAZER);
                   missile->trigger();
               }
               if (missile->destroy)
