@@ -42,7 +42,7 @@ using namespace std;
 char	*errorMessage;
 int	errorX, errorY;
 
-int	WHITE, BLACK, PINK, RED, GREEN, BLUE, PURPLE, YELLOW;
+int	WHITE, BLACK, PINK, RED, GREEN, DARK_GREEN, BLUE, PURPLE, YELLOW;
 
 int	k;
 int	ctrlUsedUp;
