@@ -641,15 +641,16 @@ void MISSILE::trigger ()
 
   if ((type >= DIRT_BALL && type <= SMALL_DIRT_SPREAD) || (type >= RIOT_CHARGE && type <= RIOT_BLAST))
     {
-      play_sample ((SAMPLE *) _global->sounds[9], 128 + (expSize / 2), 128, 1000 - (expSize * 2), 0);
+      play_sample ((SAMPLE *) _global->sounds[9], _env->scaleVolume(128 + (expSize / 2)), 128, 1000 - (expSize * 2), 0);
     }
   else if (type == NAPALM_JELLY)
     {
+      // TODO?
       //play_sample ((SAMPLE *) _global->SOUND[9].dat, 128 + (expSize / 2), 128, 1000 - (expSize * 2), 0);
     }
   else
     {
-      play_sample ((SAMPLE *) _global->sounds[WEAPONSOUNDS + sound], 255, 128, 1000, 0);
+      play_sample ((SAMPLE *) _global->sounds[WEAPONSOUNDS + sound], _env->scaleVolume(255), 128, 1000, 0);
     }
 }
 
