@@ -414,9 +414,13 @@ void *Generate_Sky_In_Background(void *new_env)
                    (my_global->ditherGradients ? GENSKY_DITHERGRAD : 0 ) |
                    (my_global->detailedSky ? GENSKY_DETAILED : 0 )  );
 
+         #ifdef THREADS
          env->lock(env->waiting_sky_lock);
+         #endif
          env->waiting_sky = sky_in_progress;
+         #ifdef THREADS
          env->unlock(env->waiting_sky_lock);
+         #endif
          sky_in_progress = NULL;
       }
 
