@@ -524,7 +524,7 @@ void TANK::applyDamage ()
     }
   else
     {
-      shieldText->set_text ( "");
+      shieldText->set_text (NULL);
     }
   sprintf (buf, "%d", l);
   healthText->set_text (buf);
@@ -692,7 +692,7 @@ void TANK::explode ()
   
 
   destroy = TRUE;
-  play_sample ((SAMPLE *)_global->sounds[WEAPONSOUNDS], 255, 128, 1000, 0);
+  play_sample ((SAMPLE *)_global->sounds[WEAPONSOUNDS], _env->scaleVolume(255), 128, 1000, 0);
 }
 
 void TANK::repulse (double xpos, double ypos, double *xaccel, double *yaccel, int aWeaponType)
@@ -1006,7 +1006,7 @@ void TANK::activateCurrentSelection ()
 
       if (cw < BALLISTICS)
         {
-          play_sample ((SAMPLE *) _global->sounds[weapon[cw].sound], 255, 128, 1000, 0);
+          play_sample ((SAMPLE *) _global->sounds[weapon[cw].sound], _env->scaleVolume(255), 128, 1000, 0);
           for (z = 0; z < _env->am; z++)
             {
               MISSILE *newmis;
@@ -1057,7 +1057,7 @@ void TANK::activateCurrentSelection ()
         }
       else          // BEAM weapon
         {
-          play_sample ((SAMPLE *) _global->sounds[weapon[cw].sound], 255, 128, 1000, 0);
+          play_sample ((SAMPLE *) _global->sounds[weapon[cw].sound], _env->scaleVolume(255), 128, 1000, 0);
           for (z = 0; z < _env->am; z++)
             {
               BEAM *newbeam;
@@ -1104,7 +1104,6 @@ void TANK::activateCurrentSelection ()
         {
           int random_tank_number;
           TANK *other_tank;
-          TELEPORT *my_teleport, *other_teleport;
 
           // pick a random tank (not us)
           random_tank_number = rand() % _global->numTanks;
@@ -1118,14 +1117,13 @@ void TANK::activateCurrentSelection ()
             }
           creditTo = player;
           // create a teleport ojbect for this tank
-          my_teleport = new TELEPORT (_global, _env, this, (int) other_tank->x, (int) other_tank->y, TANKHEIGHT * 4 + GUNLENGTH, 120);
+          new TELEPORT (_global, _env, this, (int) other_tank->x, (int) other_tank->y, TANKHEIGHT * 4 + GUNLENGTH, 120);
           // create a teleport object for the other tank
-          other_teleport = new TELEPORT (_global, _env, other_tank, (int) x, (int) y, TANKHEIGHT * 4 + GUNLENGTH, 120);
+          new TELEPORT (_global, _env, other_tank, (int) x, (int) y, TANKHEIGHT * 4 + GUNLENGTH, 120);
 
         }
       else if (itemNum == ITEM_MASS_TELEPORT)
       {
-          TELEPORT *my_teleport;
           int count;
           int XDest, YDest;
           TANK *current_tank;
@@ -1138,7 +1136,7 @@ void TANK::activateCurrentSelection ()
                 XDest = (rand () % (_global->screenWidth - TANKWIDTH * 2)) + TANKWIDTH;
                 YDest = (rand () % (_global->screenHeight - TANKHEIGHT * 2)) + TANKHEIGHT;
                 creditTo = player;
-                my_teleport = new TELEPORT(_global, _env, current_tank, XDest, YDest, TANKHEIGHT * 4 + GUNLENGTH, 120);
+                new TELEPORT(_global, _env, current_tank, XDest, YDest, TANKHEIGHT * 4 + GUNLENGTH, 120);
              }
           }
              
@@ -1163,7 +1161,7 @@ void TANK::activateCurrentSelection ()
       else if ( itemNum == ITEM_FAN )
         {
           // play wind sound
-          play_sample ((SAMPLE *) _global->sounds[2], 255, 128, 1000, 0);
+          play_sample ((SAMPLE *) _global->sounds[2], _env->scaleVolume(255), 128, 1000, 0);
           if (a < 180)   // move wind to the right
             _env->wind += (p / 20);
           else     // wind to the left
@@ -1231,7 +1229,7 @@ void TANK::boost_up_shield ()
     }
   else
     {
-      shieldText->set_text ( "");
+      shieldText->set_text (NULL);
     }
 }
 void TANK::reactivate_shield ()
